@@ -1,17 +1,17 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "netbsd1.3.1"
+#define HOST_OS "netbsd1.3.2"
 #define HOST_OS_NAME "netbsd1"
-#define HOST_OS_VERSION "1.3.1"
+#define HOST_OS_VERSION "1.3.2"
 #define HOST_ARCH "i386"
-#define HOST_NAME "london.mcl.cs.columbia.edu"
+#define HOST_NAME "london"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Wed Apr 22 14:53:40 EDT 1998"
+#define CONFIG_DATE "Wed Dec 23 07:14:26 PST 1998"
 #define PACKAGE "am-utils"
-#define VERSION "6.0a16"
+#define VERSION "6.0b2s4"
 #define PACKAGE "am-utils"
-#define VERSION "6.0a16"
+#define VERSION "6.0b2s4"
 #define DEBUG 1
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
@@ -119,6 +119,7 @@
 #define HAVE_NETINET_IF_ETHER_H 1
 #define HAVE_NETINET_IN_H 1
 #define HAVE_NFS_NFS_H 1
+#define HAVE_NFS_NFSMOUNT_H 1
 #define HAVE_NFS_NFSPROTO_H 1
 #define HAVE_NFS_RPCV2_H 1
 #define HAVE_NFS_RPCV2_H 1
@@ -213,6 +214,7 @@
 #define HAVE_EXTERN_GETWD 1
 #define HAVE_EXTERN_MKSTEMP 1
 #define HAVE_EXTERN_SBRK 1
+#define HAVE_EXTERN_SETEUID 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
 #define HAVE_EXTERN_STRSTR 1
@@ -282,16 +284,22 @@
 #define MNTTAB_TYPE_NULLFS "nullfs"
 #define MNTTAB_TYPE_UNIONFS "unionfs"
 #define MNTTAB_TYPE_UMAPFS "umapfs"
+#define MNT2_GEN_OPT_ASYNC 0x40
 #define MNT2_GEN_OPT_NODEV 0x10
 #define MNT2_GEN_OPT_NOEXEC 0x4
 #define MNT2_GEN_OPT_NOSUID 0x8
 #define MNT2_GEN_OPT_QUOTA 0x2000
 #define MNT2_GEN_OPT_RDONLY 0x1
+#define MNT2_GEN_OPT_SYNCHRONOUS 0x2
+#define MNT2_NFS_OPT_DEADTHRESH 0x4000
 #define MNT2_NFS_OPT_DUMBTIMR 0x800
 #define MNT2_NFS_OPT_INT 0x40
+#define MNT2_NFS_OPT_LEASETERM 0x1000
 #define MNT2_NFS_OPT_MAXGRPS 0x20
 #define MNT2_NFS_OPT_NFSV3 0x200
 #define MNT2_NFS_OPT_NOCONN 0x80
+#define MNT2_NFS_OPT_NQNFS 0x100
+#define MNT2_NFS_OPT_READAHEAD 0x2000
 #define MNT2_NFS_OPT_RESVPORT 0x8000
 #define MNT2_NFS_OPT_RETRANS 0x10
 #define MNT2_NFS_OPT_RSIZE 0x4
